@@ -124,5 +124,5 @@
 #endif
 
 #if defined(GSL_RANGE_CHECK_OFF) || !defined(GSL_RANGE_CHECK)
-#define GSL_RANGE_CHECK 0  /* turn off range checking by default */
+#define GSL_RANGE_CHECK 0  /* turn off range checking by default internally */
 #endif
