@@ -39,7 +39,7 @@ FUNCTION (test, func) (void)
   gsl_test (data == 0, NAME (gsl_block) "_data returns valid pointer");
   gsl_test (size != N, NAME (gsl_block) "_size returns valid size");
   
-  FUNCTION (gsl_block, free) (b);	/* free whatever is in v */
+  FUNCTION (gsl_block, free) (b);       /* free whatever is in v */
 
   b = FUNCTION (gsl_block, calloc) (N);
 
@@ -57,7 +57,7 @@ FUNCTION (test, func) (void)
   for (i = 0; i < N; i++)
     {
       if (b->data[2 * i] != 0.0 || b->data[2 * i + 1] != 0.0)
-	status = 1;
+        status = 1;
     };
 
   gsl_test (status, NAME (gsl_block) "_calloc initializes array to zero");
@@ -77,7 +77,7 @@ FUNCTION (test, binary) (void)
 
     for (i = 0; i < N; i++)
       {
-	v->data[2*i] = (ATOMIC)(N - i);
+        v->data[2*i] = (ATOMIC)(N - i);
         v->data[2*i + 1] = (ATOMIC)(10*(N-i) + 1);
       };
 
@@ -98,15 +98,15 @@ FUNCTION (test, binary) (void)
     status = 0;
     for (i = 0; i < N; i++)
       {
-	if (w->data[2 * i] != (ATOMIC) (N - i) || w->data[2 * i + 1] != (ATOMIC) (10*(N - i) + 1))
-	  status = 1;
+        if (w->data[2 * i] != (ATOMIC) (N - i) || w->data[2 * i + 1] != (ATOMIC) (10*(N - i) + 1))
+          status = 1;
       };
     fclose (f);
 
     FUNCTION (gsl_block, free) (w);
   }
 
-  gsl_test (status, NAME (gsl_block) "_write and read work correctly");
+  gsl_test (status, NAME (gsl_block) "_write and read");
 
 }
 
