@@ -1,6 +1,6 @@
 /* gsl_mode.h
  * 
- * Copyright (C) 1996, 1997, 1998, 1999, 2000 Gerard Jungman
+ * Copyright (C) 1996, 1997, 1998, 1999, 2000, 2004 Gerard Jungman
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -66,7 +66,7 @@ typedef unsigned int gsl_mode_t;
 #define GSL_PREC_SINGLE  1
 #define GSL_PREC_APPROX  2
 
-#if HAVE_INLINE
+#ifdef HAVE_INLINE
 extern inline unsigned int GSL_MODE_PREC(gsl_mode_t mt);
 
 extern inline unsigned int
