@@ -40,21 +40,21 @@
  * Problem have been reported with the "fixed" float.h installed with
  * gcc-2.95 lacking some of the definitions in the system float.h (the
  * symptoms are errors like: `FP_RND_RN' undeclared). To work around
- * this we include the system float.h before the gcc version, e.g. 
+ * this we can include the system float.h before the gcc version, e.g. 
  *
  *  #include "/usr/include/float.h"
  *  #include <float.h>
- * 
- * This is controlled by the config.h symbol 
- * `HAVE_FP_RND_IN_USR_INCLUDE_FLOAT_H'.
  */
 
-#ifdef FIND_FP_RND_IN_USR_INCLUDE_FLOAT_H
+#include <float.h>
+
+#ifndef FP_RND_RN
+#  undef _FLOAT_H_
 #  include "/usr/include/float.h"
 #  undef _FLOAT_H_
+#  include <float.h>
 #endif
 
-#include <float.h>
 #include <machine/fpu.h>
 #include <stdio.h>
 #include <gsl/gsl_ieee_utils.h>
@@ -75,15 +75,15 @@ gsl_ieee_set_mode (int precision, int rounding, int exception_mask)
     {
     case GSL_IEEE_SINGLE_PRECISION:
       GSL_ERROR ("Tru64 Unix on the alpha only supports default precision rounding",
-		 GSL_EUNSUP) ;
+                 GSL_EUNSUP) ;
       break ;
     case GSL_IEEE_DOUBLE_PRECISION:
       GSL_ERROR ("Tru64 Unix on the alpha only supports default precision rounding",
-		 GSL_EUNSUP) ;
+                 GSL_EUNSUP) ;
       break ;
     case GSL_IEEE_EXTENDED_PRECISION:
       GSL_ERROR ("Tru64 Unix on the alpha only supports default precision rounding",
-		 GSL_EUNSUP) ;
+                 GSL_EUNSUP) ;
       break ;
     }
 
@@ -114,21 +114,21 @@ gsl_ieee_set_mode (int precision, int rounding, int exception_mask)
   /* Turn on all the exceptions apart from 'inexact' */
 
   /* from the ieee(3) man page:
-   * IEEE_TRAP_ENABLE_INV	->	Invalid operation
-   * IEEE_TRAP_ENABLE_DZE	->	Divide by 0
-   * IEEE_TRAP_ENABLE_OVF	->	Overflow
-   * IEEE_TRAP_ENABLE_UNF	->	Underflow
-   * IEEE_TRAP_ENABLE_INE	->	Inexact (requires special option to C compiler)
-   * IEEE_TRAP_ENABLE_DNO	->	denormal operand
+   * IEEE_TRAP_ENABLE_INV       ->      Invalid operation
+   * IEEE_TRAP_ENABLE_DZE       ->      Divide by 0
+   * IEEE_TRAP_ENABLE_OVF       ->      Overflow
+   * IEEE_TRAP_ENABLE_UNF       ->      Underflow
+   * IEEE_TRAP_ENABLE_INE       ->      Inexact (requires special option to C compiler)
+   * IEEE_TRAP_ENABLE_DNO       ->      denormal operand
    * Note: IEEE_TRAP_ENABLE_DNO is not supported on OSF 3.x or Digital Unix
    * 4.0 - 4.0d(?).
-   * IEEE_TRAP_ENABLE_MASK	->	mask of all the trap enables
-   * IEEE_MAP_DMZ			->	map denormal inputs to zero
-   * IEEE_MAP_UMZ			->	map underflow results to zero
+   * IEEE_TRAP_ENABLE_MASK      ->      mask of all the trap enables
+   * IEEE_MAP_DMZ                       ->      map denormal inputs to zero
+   * IEEE_MAP_UMZ                       ->      map underflow results to zero
    */
 
   mode = IEEE_TRAP_ENABLE_INV | IEEE_TRAP_ENABLE_DZE | IEEE_TRAP_ENABLE_OVF
-		| IEEE_TRAP_ENABLE_UNF ;
+                | IEEE_TRAP_ENABLE_UNF ;
 
   if (exception_mask & GSL_IEEE_MASK_INVALID)
     mode &= ~ IEEE_TRAP_ENABLE_INV ;
