@@ -1,6 +1,6 @@
 /* interpolation/bsearch.h
  * 
- * Copyright (C) 1996, 1997, 1998, 1999, 2000 Gerard Jungman
+ * Copyright (C) 1996, 1997, 1998, 1999, 2000, 2004 Gerard Jungman
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -52,7 +52,7 @@ gsl_interp_bsearch(
   );
 
 
-#if HAVE_INLINE
+#ifdef HAVE_INLINE
 extern
 inline
 size_t
