@@ -23,6 +23,7 @@
 #include <stdlib.h>
 #include <gsl/gsl_types.h>
 #include <gsl/gsl_errno.h>
+#include <gsl/gsl_check_range.h>
 #include <gsl/gsl_vector_short.h>
 
 #undef __BEGIN_DECLS
@@ -237,8 +238,6 @@ int gsl_matrix_short_get_col(gsl_vector_short * v, const gsl_matrix_short * m, c
 int gsl_matrix_short_set_row(gsl_matrix_short * m, const size_t i, const gsl_vector_short * v);
 int gsl_matrix_short_set_col(gsl_matrix_short * m, const size_t j, const gsl_vector_short * v);
 
-GSL_VAR int gsl_check_range ;
-
 /* inline functions if you are using GCC */
 
 #ifdef HAVE_INLINE
@@ -246,7 +245,7 @@ extern inline
 short
 gsl_matrix_short_get(const gsl_matrix_short * m, const size_t i, const size_t j)
 {
-#ifndef GSL_RANGE_CHECK_OFF
+#if GSL_RANGE_CHECK
   if (i >= m->size1)
     {
       GSL_ERROR_VAL("first index out of range", GSL_EINVAL, 0) ;
@@ -263,7 +262,7 @@ extern inline
 void
 gsl_matrix_short_set(gsl_matrix_short * m, const size_t i, const size_t j, const short x)
 {
-#ifndef GSL_RANGE_CHECK_OFF
+#if GSL_RANGE_CHECK
   if (i >= m->size1)
     {
       GSL_ERROR_VOID("first index out of range", GSL_EINVAL) ;
@@ -280,7 +279,7 @@ extern inline
 short *
 gsl_matrix_short_ptr(gsl_matrix_short * m, const size_t i, const size_t j)
 {
-#ifndef GSL_RANGE_CHECK_OFF
+#if GSL_RANGE_CHECK
   if (i >= m->size1)
     {
       GSL_ERROR_NULL("first index out of range", GSL_EINVAL) ;
@@ -297,7 +296,7 @@ extern inline
 const short *
 gsl_matrix_short_const_ptr(const gsl_matrix_short * m, const size_t i, const size_t j)
 {
-#ifndef GSL_RANGE_CHECK_OFF
+#if GSL_RANGE_CHECK
   if (i >= m->size1)
     {
       GSL_ERROR_NULL("first index out of range", GSL_EINVAL) ;
