@@ -40,13 +40,13 @@ FUNCTION (test, func) (void)
   for (i = 0; i < M; i++)
     {
       for (j = 0; j < N; j++)
-	{
-	  BASE z = ZERO;
-	  k++;
-	  GSL_REAL (z) = (ATOMIC) k;
-	  GSL_IMAG (z) = (ATOMIC) (k + 1000);
-	  FUNCTION (gsl_matrix, set) (m, i, j, z);
-	}
+        {
+          BASE z = ZERO;
+          k++;
+          GSL_REAL (z) = (ATOMIC) k;
+          GSL_IMAG (z) = (ATOMIC) (k + 1000);
+          FUNCTION (gsl_matrix, set) (m, i, j, z);
+        }
     }
 
   status = 0;
@@ -54,12 +54,12 @@ FUNCTION (test, func) (void)
   for (i = 0; i < M; i++)
     {
       for (j = 0; j < N; j++)
-	{
-	  k++;
-	  if (m->data[2 * (i * N + j)] != k ||
-	      m->data[2 * (i * N + j) + 1] != k + 1000)
-	    status = 1;
-	}
+        {
+          k++;
+          if (m->data[2 * (i * N + j)] != k ||
+              m->data[2 * (i * N + j) + 1] != k + 1000)
+            status = 1;
+        }
     }
 
   gsl_test (status, NAME (gsl_matrix) "_set writes into array");
@@ -69,20 +69,20 @@ FUNCTION (test, func) (void)
   for (i = 0; i < M; i++)
     {
       for (j = 0; j < N; j++)
-	{
-	  BASE z = FUNCTION (gsl_matrix, get) (m, i, j);
-	  k++;
-	  if (GSL_REAL (z) != k || GSL_IMAG (z) != k + 1000)
-	    status = 1;
-	}
+        {
+          BASE z = FUNCTION (gsl_matrix, get) (m, i, j);
+          k++;
+          if (GSL_REAL (z) != k || GSL_IMAG (z) != k + 1000)
+            status = 1;
+        }
     }
   gsl_test (status, NAME (gsl_matrix) "_get reads from array");
 
-  FUNCTION (gsl_matrix, free) (m);	/* free whatever is in m */
+  FUNCTION (gsl_matrix, free) (m);      /* free whatever is in m */
 
 }
 
-#if !(defined(USES_LONGDOUBLE) && !defined(HAVE_PRINTF_LONGDOUBLE))
+#if !(USES_LONGDOUBLE && !HAVE_PRINTF_LONGDOUBLE)
 void
 FUNCTION (test, text) (void)
 {
@@ -96,14 +96,14 @@ FUNCTION (test, text) (void)
     k = 0;
     for (i = 0; i < M; i++)
       {
-	for (j = 0; j < N; j++)
-	  {
-	    BASE z;
-	    k++;
-	    GSL_REAL (z) = (ATOMIC) k;
-	    GSL_IMAG (z) = (ATOMIC) (k + 1000);
-	    FUNCTION (gsl_matrix, set) (m, i, j, z);
-	  }
+        for (j = 0; j < N; j++)
+          {
+            BASE z;
+            k++;
+            GSL_REAL (z) = (ATOMIC) k;
+            GSL_IMAG (z) = (ATOMIC) (k + 1000);
+            FUNCTION (gsl_matrix, set) (m, i, j, z);
+          }
       }
 
     FUNCTION (gsl_matrix, fprintf) (f, m, OUT_FORMAT);
@@ -120,13 +120,13 @@ FUNCTION (test, text) (void)
     k = 0;
     for (i = 0; i < M; i++)
       {
-	for (j = 0; j < N; j++)
-	  {
-	    k++;
-	    if (mm->data[2 * (i * N + j)] != k
-		|| mm->data[2 * (i * N + j) + 1] != k + 1000)
-	      status = 1;
-	  }
+        for (j = 0; j < N; j++)
+          {
+            k++;
+            if (mm->data[2 * (i * N + j)] != k
+                || mm->data[2 * (i * N + j) + 1] != k + 1000)
+              status = 1;
+          }
       }
 
     gsl_test (status, NAME (gsl_matrix) "_fprintf and fscanf");
@@ -152,14 +152,14 @@ FUNCTION (test, binary) (void)
     k = 0;
     for (i = 0; i < M; i++)
       {
-	for (j = 0; j < N; j++)
-	  {
-	    BASE z = ZERO;
-	    k++;
-	    GSL_REAL (z) = (ATOMIC) k;
-	    GSL_IMAG (z) = (ATOMIC) (k + 1000);
-	    FUNCTION (gsl_matrix, set) (m, i, j, z);
-	  }
+        for (j = 0; j < N; j++)
+          {
+            BASE z = ZERO;
+            k++;
+            GSL_REAL (z) = (ATOMIC) k;
+            GSL_IMAG (z) = (ATOMIC) (k + 1000);
+            FUNCTION (gsl_matrix, set) (m, i, j, z);
+          }
       }
 
     FUNCTION (gsl_matrix, fwrite) (f, m);
@@ -176,13 +176,13 @@ FUNCTION (test, binary) (void)
     k = 0;
     for (i = 0; i < M; i++)
       {
-	for (j = 0; j < N; j++)
-	  {
-	    k++;
-	    if (mm->data[2 * (i * N + j)] != k
-		|| mm->data[2 * (i * N + j) + 1] != k + 1000)
-	      status = 1;
-	  }
+        for (j = 0; j < N; j++)
+          {
+            k++;
+            if (mm->data[2 * (i * N + j)] != k
+                || mm->data[2 * (i * N + j) + 1] != k + 1000)
+              status = 1;
+          }
       }
 
     gsl_test (status, NAME (gsl_matrix) "_write and read");
@@ -206,22 +206,22 @@ FUNCTION (test, trap) (void)
   status = 0;
   FUNCTION (gsl_matrix, set) (mc, i - 1, j, z);
   gsl_test (!status,
-	    NAME (gsl_matrix) "_set traps 1st index below lower bound");
+            NAME (gsl_matrix) "_set traps 1st index below lower bound");
 
   status = 0;
   FUNCTION (gsl_matrix, set) (mc, i, j - 1, z);
   gsl_test (!status,
-	    NAME (gsl_matrix) "_set traps 2nd index below lower bound");
+            NAME (gsl_matrix) "_set traps 2nd index below lower bound");
 
   status = 0;
   FUNCTION (gsl_matrix, set) (mc, M + 1, 0, z);
   gsl_test (!status,
-	    NAME (gsl_matrix) "_set traps 1st index above upper bound");
+            NAME (gsl_matrix) "_set traps 1st index above upper bound");
 
   status = 0;
   FUNCTION (gsl_matrix, set) (mc, 0, N + 1, z);
   gsl_test (!status,
-	    NAME (gsl_matrix) "_set traps 2nd index above upper bound");
+            NAME (gsl_matrix) "_set traps 2nd index above upper bound");
 
   status = 0;
   FUNCTION (gsl_matrix, set) (mc, M, 0, z);
@@ -234,54 +234,54 @@ FUNCTION (test, trap) (void)
   status = 0;
   z1 = FUNCTION (gsl_matrix, get) (mc, i - 1, 0);
   gsl_test (!status,
-	    NAME (gsl_matrix) "_get traps 1st index below lower bound");
+            NAME (gsl_matrix) "_get traps 1st index below lower bound");
   gsl_test (GSL_REAL (z1) != 0,
-	    NAME (gsl_matrix) "_get, zero real for 1st index below l.b.");
+            NAME (gsl_matrix) "_get, zero real for 1st index below l.b.");
   gsl_test (GSL_IMAG (z1) != 0,
-	    NAME (gsl_matrix) "_get, zero imag for 1st index below l.b.");
+            NAME (gsl_matrix) "_get, zero imag for 1st index below l.b.");
 
   status = 0;
   z1 = FUNCTION (gsl_matrix, get) (mc, 0, j - 1);
   gsl_test (!status,
-	    NAME (gsl_matrix) "_get traps 2nd index below lower bound");
+            NAME (gsl_matrix) "_get traps 2nd index below lower bound");
   gsl_test (GSL_REAL (z1) != 0,
-	    NAME (gsl_matrix) "_get, zero real for 2nd index below l.b.");
+            NAME (gsl_matrix) "_get, zero real for 2nd index below l.b.");
   gsl_test (GSL_IMAG (z1) != 0,
-	    NAME (gsl_matrix) "_get, zero imag for 2nd index below l.b.");
+            NAME (gsl_matrix) "_get, zero imag for 2nd index below l.b.");
 
   status = 0;
   z1 = FUNCTION (gsl_matrix, get) (mc, M + 1, 0);
   gsl_test (!status,
-	    NAME (gsl_matrix) "_get traps 1st index above upper bound");
+            NAME (gsl_matrix) "_get traps 1st index above upper bound");
   gsl_test (GSL_REAL (z1) != 0,
-	    NAME (gsl_matrix) "_get, zero real for 1st index above u.b.");
+            NAME (gsl_matrix) "_get, zero real for 1st index above u.b.");
   gsl_test (GSL_IMAG (z1) != 0,
-	    NAME (gsl_matrix) "_get, zero imag for 1st index above u.b.");
+            NAME (gsl_matrix) "_get, zero imag for 1st index above u.b.");
 
   status = 0;
   z1 = FUNCTION (gsl_matrix, get) (mc, 0, N + 1);
   gsl_test (!status,
-	    NAME (gsl_matrix) "_get traps 2nd index above upper bound");
+            NAME (gsl_matrix) "_get traps 2nd index above upper bound");
   gsl_test (GSL_REAL (z1) != 0,
-	    NAME (gsl_matrix) "_get, zero real for 2nd index above u.b.");
+            NAME (gsl_matrix) "_get, zero real for 2nd index above u.b.");
   gsl_test (GSL_IMAG (z1) != 0,
-	    NAME (gsl_matrix) "_get, zero imag for 2nd index above u.b.");
+            NAME (gsl_matrix) "_get, zero imag for 2nd index above u.b.");
 
   status = 0;
   z1 = FUNCTION (gsl_matrix, get) (mc, M, 0);
   gsl_test (!status, NAME (gsl_matrix) "_get traps 1st index at upper bound");
   gsl_test (GSL_REAL (z1) != 0,
-	    NAME (gsl_matrix) "_get, zero real for 1st index at u.b.");
+            NAME (gsl_matrix) "_get, zero real for 1st index at u.b.");
   gsl_test (GSL_IMAG (z1) != 0,
-	    NAME (gsl_matrix) "_get, zero imag for 1st index at u.b.");
+            NAME (gsl_matrix) "_get, zero imag for 1st index at u.b.");
 
   status = 0;
   z1 = FUNCTION (gsl_matrix, get) (mc, 0, N);
   gsl_test (!status, NAME (gsl_matrix) "_get traps 2nd index at upper bound");
   gsl_test (GSL_REAL (z1) != 0,
-	    NAME (gsl_matrix) "_get, zero real for 2nd index at u.b.");
+            NAME (gsl_matrix) "_get, zero real for 2nd index at u.b.");
   gsl_test (GSL_IMAG (z1) != 0,
-	    NAME (gsl_matrix) "_get, zero imag for 2nd index at u.b.");
+            NAME (gsl_matrix) "_get, zero imag for 2nd index at u.b.");
 
   FUNCTION (gsl_matrix, free) (mc);
 }
@@ -306,17 +306,17 @@ FUNCTION (test, arith) (void)
   for (i = 0; i < P; i++)
     {
       for (j = 0; j < Q; j++)
-	{
-	  BASE z, z1;
-	  GSL_REAL (z) = (ATOMIC) k;
-	  GSL_IMAG (z) = (ATOMIC) (k + 10);
-	  GSL_REAL (z1) = (ATOMIC) (k + 5);
-	  GSL_IMAG (z1) = (ATOMIC) (k + 20);
+        {
+          BASE z, z1;
+          GSL_REAL (z) = (ATOMIC) k;
+          GSL_IMAG (z) = (ATOMIC) (k + 10);
+          GSL_REAL (z1) = (ATOMIC) (k + 5);
+          GSL_IMAG (z1) = (ATOMIC) (k + 20);
 
-	  FUNCTION (gsl_matrix, set) (a, i, j, z);
-	  FUNCTION (gsl_matrix, set) (b, i, j, z1);
-	  k++;
-	}
+          FUNCTION (gsl_matrix, set) (a, i, j, z);
+          FUNCTION (gsl_matrix, set) (b, i, j, z1);
+          k++;
+        }
     }
 
   {
@@ -329,14 +329,14 @@ FUNCTION (test, arith) (void)
 
     for (i = 0; i < P; i++)
       {
-	for (j = 0; j < Q; j++)
-	  {
-	    BASE z = FUNCTION (gsl_matrix, get) (m, i, j);
-	    if (GSL_REAL (z) != (ATOMIC) (2 * k + 5) ||
-		GSL_IMAG (z) != (ATOMIC) (2 * k + 30))
-	      status = 1;
-	    k++;
-	  }
+        for (j = 0; j < Q; j++)
+          {
+            BASE z = FUNCTION (gsl_matrix, get) (m, i, j);
+            if (GSL_REAL (z) != (ATOMIC) (2 * k + 5) ||
+                GSL_IMAG (z) != (ATOMIC) (2 * k + 30))
+              status = 1;
+            k++;
+          }
       }
     gsl_test (status, NAME (gsl_matrix) "_add matrix addition");
   }
@@ -351,14 +351,14 @@ FUNCTION (test, arith) (void)
 
     for (i = 0; i < P; i++)
       {
-	for (j = 0; j < Q; j++)
-	  {
-	    BASE z = FUNCTION (gsl_matrix, get) (m, i, j);
-	    if (GSL_REAL (z) != (ATOMIC) (-5)
-		|| GSL_IMAG (z) != (ATOMIC) (-10))
-	      status = 1;
-	    k++;
-	  }
+        for (j = 0; j < Q; j++)
+          {
+            BASE z = FUNCTION (gsl_matrix, get) (m, i, j);
+            if (GSL_REAL (z) != (ATOMIC) (-5)
+                || GSL_IMAG (z) != (ATOMIC) (-10))
+              status = 1;
+            k++;
+          }
       }
     gsl_test (status, NAME (gsl_matrix) "_sub matrix subtraction");
   }
@@ -373,26 +373,26 @@ FUNCTION (test, arith) (void)
 
     for (i = 0; i < P; i++)
       {
-	for (j = 0; j < Q; j++)
-	  {
-	    ATOMIC real = -(ATOMIC) (25 * k + 200);
-	    ATOMIC imag = (ATOMIC) (2 * k * k + 35 * k + 50);
-	    BASE z = FUNCTION (gsl_matrix, get) (m, i, j);
-	    if (fabs (GSL_REAL (z) - real) > 100 * BASE_EPSILON ||
-		fabs (GSL_IMAG (z) - imag) > 100 * BASE_EPSILON)
-	      {
-		status = 1;
+        for (j = 0; j < Q; j++)
+          {
+            ATOMIC real = -(ATOMIC) (25 * k + 200);
+            ATOMIC imag = (ATOMIC) (2 * k * k + 35 * k + 50);
+            BASE z = FUNCTION (gsl_matrix, get) (m, i, j);
+            if (fabs (GSL_REAL (z) - real) > 100 * BASE_EPSILON ||
+                fabs (GSL_IMAG (z) - imag) > 100 * BASE_EPSILON)
+              {
+                status = 1;
 #ifdef DEBUG
-		printf ("%d\t%d\n", i, j);
-		printf (OUT_FORMAT "\n",
-			GSL_REAL (z) + (ATOMIC) (25 * (ATOMIC) k + 200));
-		printf (OUT_FORMAT "\n",
-			GSL_IMAG (z) - (ATOMIC) (2 * k * k + 35 * k + 50));
-		printf ("\n");
+                printf ("%d\t%d\n", i, j);
+                printf (OUT_FORMAT "\n",
+                        GSL_REAL (z) + (ATOMIC) (25 * (ATOMIC) k + 200));
+                printf (OUT_FORMAT "\n",
+                        GSL_IMAG (z) - (ATOMIC) (2 * k * k + 35 * k + 50));
+                printf ("\n");
 #endif
-	      }
-	    k++;
-	  }
+              }
+            k++;
+          }
       }
     gsl_test (status, NAME (gsl_matrix) "_mul_elements multiplication");
   }
@@ -408,27 +408,27 @@ FUNCTION (test, arith) (void)
 
     for (i = 0; i < P; i++)
       {
-	for (j = 0; j < Q; j++)
-	  {
-	    ATOMIC denom = (2 * k * k + 50 * k + 425);
-	    ATOMIC real = (ATOMIC) (2 * k * k + 35 * k + 200) / denom;
-	    ATOMIC imag = ((ATOMIC) (50) - (ATOMIC) (5 * k)) / denom;
-	    BASE z = FUNCTION (gsl_matrix, get) (m, i, j);
-	    if (fabs (GSL_REAL (z) - real) > 100 * BASE_EPSILON ||
-		fabs (GSL_IMAG (z) - imag) > 100 * BASE_EPSILON)
-	      {
+        for (j = 0; j < Q; j++)
+          {
+            ATOMIC denom = (2 * k * k + 50 * k + 425);
+            ATOMIC real = (ATOMIC) (2 * k * k + 35 * k + 200) / denom;
+            ATOMIC imag = ((ATOMIC) (50) - (ATOMIC) (5 * k)) / denom;
+            BASE z = FUNCTION (gsl_matrix, get) (m, i, j);
+            if (fabs (GSL_REAL (z) - real) > 100 * BASE_EPSILON ||
+                fabs (GSL_IMAG (z) - imag) > 100 * BASE_EPSILON)
+              {
 #ifdef DEBUG
-		printf (OUT_FORMAT "\t",
-			GSL_REAL (z) - (ATOMIC) (2 * k * k + 35 * k +
-						 200) / denom);
-		printf (OUT_FORMAT "\n",
-			GSL_IMAG (z) - ((ATOMIC) (50) -
-					(ATOMIC) (5 * k)) / denom);
+                printf (OUT_FORMAT "\t",
+                        GSL_REAL (z) - (ATOMIC) (2 * k * k + 35 * k +
+                                                 200) / denom);
+                printf (OUT_FORMAT "\n",
+                        GSL_IMAG (z) - ((ATOMIC) (50) -
+                                        (ATOMIC) (5 * k)) / denom);
 #endif
-		status = 1;
-	      }
-	    k++;
-	  }
+                status = 1;
+              }
+            k++;
+          }
       }
     gsl_test (status, NAME (gsl_matrix) "_div_elements division");
   }
