@@ -20,7 +20,7 @@
 #include <config.h>
 #include <gsl/gsl_math.h>
 #include <gsl/gsl_errno.h>
-#include <gsl/gsl_multifit.h>
+#include <gsl/gsl_multifit_nlin.h>
 #include <gsl/gsl_blas.h>
 
 int
