@@ -34,7 +34,7 @@ gsl_ran_binomial (const gsl_rng * r, double p, unsigned int n)
 {
   unsigned int i, a, b, k = 0;
 
-  while (n > 10)	/* This parameter is tunable */
+  while (n > 10)        /* This parameter is tunable */
     {
       double X;
       a = 1 + (n / 2);
@@ -43,45 +43,44 @@ gsl_ran_binomial (const gsl_rng * r, double p, unsigned int n)
       X = gsl_ran_beta (r, (double) a, (double) b);
 
       if (X >= p)
-	{
-	  n = a - 1;
-	  p /= X;
-	}
+        {
+          n = a - 1;
+          p /= X;
+        }
       else
-	{
-	  k += a;
-	  n = b - 1;
-	  p = (p - X) / (1 - X);
-	}
+        {
+          k += a;
+          n = b - 1;
+          p = (p - X) / (1 - X);
+        }
     }
 
   for (i = 0; i < n; i++)
     {
       double u = gsl_rng_uniform (r);
       if (u < p)
-	k++;
+        k++;
     }
 
   return k;
 }
 
 double
-gsl_ran_binomial_pdf (const unsigned int k, const double p, 
-		      const unsigned int n)
+gsl_ran_binomial_pdf (const unsigned int k, const double p,
+                      const unsigned int n)
 {
   if (k > n)
     {
-      return 0 ;
+      return 0;
     }
-  else 
+  else
     {
-      double a = k;
-      double b = n - k;
       double P;
-      double Cnk = gsl_sf_choose (n, k) ;
 
-      P = Cnk * pow (p, a) * pow (1 - p, b);
-      
+      double ln_Cnk = gsl_sf_lnchoose (n, k);
+      P = ln_Cnk + k * log (p) + (n - k) * log (1 - p);
+      P = exp (P);
+
       return P;
     }
 }
