@@ -28,7 +28,7 @@
 #define SAFE_FUNC_CALL(f, x, yp) \
 do { \
   *yp = GSL_FN_EVAL(f,x); \
-  if (!GSL_IS_REAL(*yp)) \
+  if (!finite(*yp)) \
     GSL_ERROR("function not continuous", GSL_EBADFUNC); \
 } while (0)
 
