@@ -23,7 +23,7 @@
 #include <gsl/gsl_math.h>
 #include <gsl/gsl_errno.h>
 #include <gsl/gsl_mode.h>
-#include "gsl_sf_expint.h"
+#include <gsl/gsl_sf_expint.h>
 
 #include "chebyshev.h"
 #include "cheb_eval.c"
