@@ -25,8 +25,8 @@
 #include <gsl/gsl_mode.h>
 #include "bessel.h"
 #include "bessel_amp_phase.h"
-#include "gsl_sf_trig.h"
-#include "gsl_sf_bessel.h"
+#include <gsl/gsl_sf_trig.h>
+#include <gsl/gsl_sf_bessel.h>
 
 #include "cheb_eval.c"
 
@@ -37,11 +37,11 @@
 
 /* chebyshev expansions for Bessel functions
 
- series for bj0        on the interval  0.	    to  1.60000d+01
-					with weighted error   7.47e-18
-					 log weighted error  17.13
-			       significant figures required  16.98
-				    decimal places required  17.68
+ series for bj0        on the interval  0.          to  1.60000d+01
+                                        with weighted error   7.47e-18
+                                         log weighted error  17.13
+                               significant figures required  16.98
+                                    decimal places required  17.68
 
 */
 
