@@ -79,7 +79,7 @@ int gsl_sf_bessel_Jn_e(int n, double x, gsl_sf_result * result)
       result->err += GSL_DBL_EPSILON * fabs(result->val);
       return status;
     }
-    else if(GSL_ROOT3_DBL_EPSILON * x > (n*n+1.0)) {
+    else if(GSL_ROOT4_DBL_EPSILON * x > (n*n+1.0)) {
       int status = gsl_sf_bessel_Jnu_asympx_e((double)n, x, result);
       result->val *= sign;
       return status;
@@ -89,6 +89,15 @@ int gsl_sf_bessel_Jn_e(int n, double x, gsl_sf_result * result)
       result->val *= sign;
       return status;
     }
+    else if(x > 1000.0)
+    {
+      /* We need this to avoid feeding large x to CF1; note that
+       * due to the above check, we know that n <= 50.
+       */
+      int status = gsl_sf_bessel_Jnu_asympx_e((double)n, x, result);
+      result->val *= sign;
+      return status;      
+    }
     else {
       double ans;
       double err;
@@ -104,22 +113,22 @@ int gsl_sf_bessel_Jn_e(int n, double x, gsl_sf_result * result)
       int k;
 
       for(k=n; k>0; k--) {
-	Jkm1 = 2.0*k/x * Jk - Jkp1;
-	Jkp1 = Jk;
-	Jk   = Jkm1;
+        Jkm1 = 2.0*k/x * Jk - Jkp1;
+        Jkp1 = Jk;
+        Jk   = Jkm1;
       }
 
       if(fabs(Jkp1) > fabs(Jk)) {
         gsl_sf_result b1;
-	stat_b = gsl_sf_bessel_J1_e(x, &b1);
-	ans = b1.val/Jkp1 * GSL_SQRT_DBL_MIN;
-	err = b1.err/Jkp1 * GSL_SQRT_DBL_MIN;
+        stat_b = gsl_sf_bessel_J1_e(x, &b1);
+        ans = b1.val/Jkp1 * GSL_SQRT_DBL_MIN;
+        err = b1.err/Jkp1 * GSL_SQRT_DBL_MIN;
       }
       else {
         gsl_sf_result b0;
-	stat_b = gsl_sf_bessel_J0_e(x, &b0);
-	ans = b0.val/Jk * GSL_SQRT_DBL_MIN;
-	err = b0.err/Jk * GSL_SQRT_DBL_MIN;
+        stat_b = gsl_sf_bessel_J0_e(x, &b0);
+        ans = b0.val/Jk * GSL_SQRT_DBL_MIN;
+        err = b0.err/Jk * GSL_SQRT_DBL_MIN;
       }
 
       result->val = sign * ans;
