@@ -98,6 +98,14 @@ gsl_sf_bessel_Jnu_e(const double nu, const double x, gsl_sf_result * result)
   else if(nu > 50.0) {
     return gsl_sf_bessel_Jnu_asymp_Olver_e(nu, x, result);
   }
+  else if(x > 1000.0)
+  {
+    /* We need this to avoid feeding large x to CF1; note that
+     * due to the above check, we know that n <= 50. See similar
+     * block in bessel_Jn.c.
+     */
+    return gsl_sf_bessel_Jnu_asympx_e(nu, x, result);
+  }
   else {
     /* -1/2 <= mu <= 1/2 */
     int N = (int)(nu + 0.5);
@@ -122,8 +130,8 @@ gsl_sf_bessel_Jnu_e(const double nu, const double x, gsl_sf_result * result)
       int n;
       for(n=1; n<N; n++) {
         Ynp1 = 2.0*(mu+n)/x * Yn - Ynm1;
-	Ynm1 = Yn;
-	Yn   = Ynp1;
+        Ynm1 = Yn;
+        Yn   = Ynp1;
       }
 
       result->val = 2.0/(M_PI*x) / (Jnup1_Jnu*Yn - Ynp1);
