@@ -17,13 +17,12 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* Author:  G. Jungman
- * RCS:     $Id: bessel_olver.h,v 1.7 2001/04/23 09:38:29 bjg Exp $
- */
+/* Author:  G. Jungman */
+
 #ifndef BESSEL_OLVER_H_
 #define BESSEL_OLVER_H_
 
-#include "gsl_sf_result.h"
+#include <gsl/gsl_sf_result.h>
 
 int gsl_sf_bessel_Jnu_asymp_Olver_e(double nu, double x, gsl_sf_result * result);
 int gsl_sf_bessel_Ynu_asymp_Olver_e(double nu, double x, gsl_sf_result * result);
