@@ -162,7 +162,7 @@ int gsl_vector_add_constant (gsl_vector * a, const double x);
 
 int gsl_vector_isnull (const gsl_vector * v);
 
-#if HAVE_INLINE
+#ifdef HAVE_INLINE
 
 extern inline
 double
